@@ -2,7 +2,6 @@
 
 from django.core.management.base import BaseCommand
 from balafon.Crm import models
-from datetime import date
 
 
 class Command(BaseCommand):
@@ -13,7 +12,7 @@ class Command(BaseCommand):
         verbose = options.get('verbosity', 0)
 
         if len(args) < 1:
-            print "usage : change_entity_type new_type_name [old_type_id] [group=group_id]"
+            print("usage : change_entity_type new_type_name [old_type_id] [group=group_id]")
             return
         
         new_type_name = args[0]
@@ -27,12 +26,11 @@ class Command(BaseCommand):
         entity_type, is_new = models.EntityType.objects.get_or_create(name=new_type_name)
         
         if is_new and verbose:
-            print "Entity type", new_type_name, "has been created"
+            print("Entity type", new_type_name, "has been created")
         
         for e in qs:
             e.type = entity_type
             e.save()
         
         if verbose:
-            print qs.count(), "entities updated"
-        
\ No newline at end of file
+            print(qs.count(), "entities updated")
