@@ -8,14 +8,14 @@ from balafon.Crm.settings import ALLOW_SINGLE_CONTACT
 
 
 class Command(BaseCommand):
-    help = u"add a new credit of emailings"
+    help = "add a new credit of emailings"
     use_argparse = False
 
     def handle(self, *args, **options):
         verbose = options.get('verbosity', 0)
 
         if ALLOW_SINGLE_CONTACT:
-            print "this command is disabled if BALAFON_ALLOW_SINGLE_CONTACT is set"
+            print("this command is disabled if BALAFON_ALLOW_SINGLE_CONTACT is set")
             return
         
         individual_entity_id = getattr(settings, 'BALAFON_INDIVIDUAL_ENTITY_ID', 1)
@@ -25,5 +25,5 @@ class Command(BaseCommand):
             entity.save()
         
             if verbose:
-                print entity.name
-        print models.Entity.objects.filter(type__id=individual_entity_id).count(), "entities have been renamed"
+                print(entity.name)
+        print(models.Entity.objects.filter(type__id=individual_entity_id).count(), "entities have been renamed")
