@@ -3,13 +3,15 @@
 
 import json
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
 
 from coop_cms.tests import BeautifulSoup
 from model_mommy import mommy
 
+from balafon.unit_tests import response_as_json
 from balafon.Crm import models
 from balafon.Crm.tests import BaseTestCase
+from balafon.Users.models import UserPermissions
 
 
 class GroupTest(BaseTestCase):
@@ -80,6 +82,72 @@ class GroupTest(BaseTestCase):
         self.assertEqual(group.name, data['group_name'])
         self.assertEqual(list(group.entities.all()), [entity])
 
+    def test_create_group_not_allowed(self):
+        """add entity to existing group"""
+        UserPermissions.objects.create(user=self.user, can_create_group=False)
+        entity = mommy.make(models.Entity)
+        data = {
+            'group_name': 'toto',
+        }
+        url = reverse('crm_add_entity_to_group', args=[entity.id])
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        self.assertNotContains(response, reverse('crm_view_entity', args=[entity.id]))
+        self.assertEqual(0, models.Group.objects.count())
+        soup = BeautifulSoup(response.content)
+        self.assertEqual(len(soup.select('.field-error')), 1)
+
+    def test_add_group_existing_not_allowed_to_create(self):
+        """add entity to existing group"""
+        UserPermissions.objects.create(user=self.user, can_create_group=False)
+        group = mommy.make(models.Group, name='toto')
+        entity = mommy.make(models.Entity)
+        data = {
+            'group_name': group.name
+        }
+        url = reverse('crm_add_entity_to_group', args=[entity.id])
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        self.assertContains(response, reverse('crm_view_entity', args=[entity.id]))
+
+        self.assertEqual(1, models.Group.objects.count())
+        group = models.Group.objects.all()[0]
+        self.assertEqual(group.name, data['group_name'])
+        self.assertEqual(list(group.entities.all()), [entity])
+
+    def test_create_group_not_allowed_for_contact(self):
+        """add entity to existing group"""
+        UserPermissions.objects.create(user=self.user, can_create_group=False)
+        contact = mommy.make(models.Contact)
+        data = {
+            'group_name': 'toto',
+        }
+        url = reverse('crm_add_contact_to_group', args=[contact.id])
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        self.assertNotContains(response, reverse('crm_view_entity', args=[contact.id]))
+        self.assertEqual(0, models.Group.objects.count())
+        soup = BeautifulSoup(response.content)
+        self.assertEqual(len(soup.select('.field-error')), 1)
+
+    def test_add_group_existing_not_allowed_to_create_for_contact(self):
+        """add entity to existing group"""
+        UserPermissions.objects.create(user=self.user, can_create_group=False)
+        group = mommy.make(models.Group, name='toto')
+        contact = mommy.make(models.Contact)
+        data = {
+            'group_name': group.name
+        }
+        url = reverse('crm_add_contact_to_group', args=[contact.id])
+        response = self.client.post(url, data=data)
+        self.assertEqual(200, response.status_code)
+        self.assertContains(response, reverse('crm_view_contact', args=[contact.id]))
+
+        self.assertEqual(1, models.Group.objects.count())
+        group = models.Group.objects.all()[0]
+        self.assertEqual(group.name, data['group_name'])
+        self.assertEqual(list(group.contacts.all()), [contact])
+
     def test_add_already_in_group(self):
         """add entity already in group"""
 
@@ -459,7 +527,7 @@ class GroupSuggestListTestCase(BaseTestCase):
         response = self.client.get(reverse(self.view_name)+'?term=c')
         self.assertEqual(302, response.status_code)
         #login url without lang prefix
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
 
@@ -470,29 +538,29 @@ class ContactAndEntitySuggestListTestCase(BaseTestCase):
     def test_get_contact_and_entity(self):
         """It should return contact and entity"""
 
-        entity1 = mommy.make(models.Entity, name=u"Abc")
+        entity1 = mommy.make(models.Entity, name="Abc")
         contact1 = entity1.default_contact
-        contact1.lastname = u'Abbes'
+        contact1.lastname = 'Abbes'
         contact1.save()
 
-        entity2 = mommy.make(models.Entity, name=u"Rab")
+        entity2 = mommy.make(models.Entity, name="Rab")
         contact2 = entity2.default_contact
-        contact2.lastname = u'Plabo'
+        contact2.lastname = 'Plabo'
         contact2.save()
 
-        entity3 = mommy.make(models.Entity, name=u"ABO")
+        entity3 = mommy.make(models.Entity, name="ABO")
         contact3 = entity3.default_contact
-        contact3.lastname = u'Wab'
+        contact3.lastname = 'Wab'
         contact3.save()
 
         entity4 = mommy.make(models.Entity, name="Waw")
         contact4 = entity4.default_contact
-        contact4.lastname = u'Aby'
+        contact4.lastname = 'Aby'
         contact4.save()
 
         response = self.client.get(reverse(self.view_name)+'?term=ab')
         self.assertEqual(200, response.status_code)
-        data = json.loads(response.content)
+        data = response_as_json(response)
 
         self.assertEqual(len(data), 4)
 
@@ -509,43 +577,43 @@ class ContactAndEntitySuggestListTestCase(BaseTestCase):
     def test_get_contact_and_entity_empty(self):
         """It should return empty"""
 
-        entity1 = mommy.make(models.Entity, name=u"Abc")
+        entity1 = mommy.make(models.Entity, name="Abc")
         contact1 = entity1.default_contact
-        contact1.lastname = u'Abbes'
+        contact1.lastname = 'Abbes'
         contact1.save()
 
-        entity2 = mommy.make(models.Entity, name=u"Rab")
+        entity2 = mommy.make(models.Entity, name="Rab")
         contact2 = entity2.default_contact
-        contact2.lastname = u'Plabo'
+        contact2.lastname = 'Plabo'
         contact2.save()
 
-        entity3 = mommy.make(models.Entity, name=u"ABO")
+        entity3 = mommy.make(models.Entity, name="ABO")
         contact3 = entity3.default_contact
-        contact3.lastname = u'Wab'
+        contact3.lastname = 'Wab'
         contact3.save()
 
         entity4 = mommy.make(models.Entity, name="Waw")
         contact4 = entity4.default_contact
-        contact4.lastname = u'Aby'
+        contact4.lastname = 'Aby'
         contact4.save()
 
         response = self.client.get(reverse(self.view_name)+'?term=zzzzzzz')
         self.assertEqual(200, response.status_code)
-        data = json.loads(response.content)
+        data = response_as_json(response)
 
         self.assertEqual(len(data), 0)
 
     def test_get_contact_and_entity_invalid_url(self):
         """It should return empty"""
 
-        entity1 = mommy.make(models.Entity, name=u"Abc")
+        entity1 = mommy.make(models.Entity, name="Abc")
         contact1 = entity1.default_contact
-        contact1.lastname = u'Abbes'
+        contact1.lastname = 'Abbes'
         contact1.save()
 
         response = self.client.get(reverse(self.view_name)+'?zz=Ab')
         self.assertEqual(200, response.status_code)
-        data = json.loads(response.content)
+        data = response_as_json(response)
 
         self.assertEqual(len(data), 0)
 
@@ -554,14 +622,14 @@ class ContactAndEntitySuggestListTestCase(BaseTestCase):
 
         self.client.logout()
 
-        entity1 = mommy.make(models.Entity, name=u"Abc")
+        entity1 = mommy.make(models.Entity, name="Abc")
         contact1 = entity1.default_contact
-        contact1.lastname = u'Abbes'
+        contact1.lastname = 'Abbes'
         contact1.save()
 
         response = self.client.get(reverse(self.view_name)+'?term=zzzzzzz')
         self.assertEqual(302, response.status_code)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_get_contact_and_entity_forbidden(self):
@@ -570,14 +638,14 @@ class ContactAndEntitySuggestListTestCase(BaseTestCase):
         self.user.is_staff = False
         self.user.save()
 
-        entity1 = mommy.make(models.Entity, name=u"Abc")
+        entity1 = mommy.make(models.Entity, name="Abc")
         contact1 = entity1.default_contact
-        contact1.lastname = u'Abbes'
+        contact1.lastname = 'Abbes'
         contact1.save()
 
         response = self.client.get(reverse(self.view_name)+'?term=zzzzzzz')
         self.assertEqual(302, response.status_code)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
 
@@ -626,6 +694,7 @@ class EditGroupTestCase(BaseTestCase):
             'description': 'my group description',
             'fore_color': '',
             'background_color': '',
+            'on_contacts_list': False,
         }
         response = self.client.post(reverse('crm_edit_group', args=[group.id]), data=data)
         self.assertEqual(302, response.status_code)
@@ -635,6 +704,7 @@ class EditGroupTestCase(BaseTestCase):
         self.assertEqual(group.description, data['description'])
         self.assertEqual(group.fore_color, data['fore_color'])
         self.assertEqual(group.background_color, data['background_color'])
+        self.assertEqual(group.on_contacts_list, data['on_contacts_list'])
 
     def test_edit_group_fore_color(self):
         """it should modify the group"""
@@ -644,6 +714,7 @@ class EditGroupTestCase(BaseTestCase):
             'description': 'my group description',
             'fore_color': '#ccc',
             'background_color': '',
+            'on_contacts_list': False,
         }
         response = self.client.post(reverse('crm_edit_group', args=[group.id]), data=data)
         self.assertEqual(302, response.status_code)
@@ -651,7 +722,7 @@ class EditGroupTestCase(BaseTestCase):
         self.assertEqual(group.name, data['name'])
         self.assertEqual(group.description, data['description'])
         self.assertEqual(group.fore_color, data['fore_color'])
-        self.assertEqual(group.background_color, data['background_color'])
+        self.assertEqual(group.on_contacts_list, data['on_contacts_list'])
 
     def test_edit_group_background_color(self):
         """it should modify the group"""
@@ -661,6 +732,7 @@ class EditGroupTestCase(BaseTestCase):
             'description': 'my group description',
             'fore_color': '',
             'background_color': '#123456',
+            'on_contacts_list': False,
         }
         response = self.client.post(reverse('crm_edit_group', args=[group.id]), data=data)
         self.assertEqual(302, response.status_code)
@@ -669,6 +741,7 @@ class EditGroupTestCase(BaseTestCase):
         self.assertEqual(group.description, data['description'])
         self.assertEqual(group.fore_color, data['fore_color'])
         self.assertEqual(group.background_color, data['background_color'])
+        self.assertEqual(group.on_contacts_list, data['on_contacts_list'])
 
     def test_edit_group_invalid_color(self):
         """it should not modify the group"""
@@ -678,6 +751,7 @@ class EditGroupTestCase(BaseTestCase):
             'description': 'my group description',
             'fore_color': 'hello',
             'background_color': '#123456',
+            'on_contacts_list': False,
         }
         response = self.client.post(reverse('crm_edit_group', args=[group.id]), data=data)
         self.assertEqual(200, response.status_code)
@@ -692,6 +766,7 @@ class EditGroupTestCase(BaseTestCase):
         self.assertNotEqual(group.description, data['description'])
         self.assertNotEqual(group.fore_color, data['fore_color'])
         self.assertNotEqual(group.background_color, data['background_color'])
+        self.assertEqual(group.on_contacts_list, data['on_contacts_list'])
 
     def test_edit_group_invalid_background_color(self):
         """it should not modify the group"""
@@ -701,6 +776,7 @@ class EditGroupTestCase(BaseTestCase):
             'description': 'my group description',
             'fore_color': '#123',
             'background_color': 'hello',
+            'on_contacts_list': False,
         }
         response = self.client.post(reverse('crm_edit_group', args=[group.id]), data=data)
         self.assertEqual(200, response.status_code)
@@ -715,6 +791,46 @@ class EditGroupTestCase(BaseTestCase):
         self.assertNotEqual(group.description, data['description'])
         self.assertNotEqual(group.fore_color, data['fore_color'])
         self.assertNotEqual(group.background_color, data['background_color'])
+        self.assertEqual(group.on_contacts_list, data['on_contacts_list'])
+
+    def test_edit_group_on_contacts_list(self):
+        """it should modify the group"""
+        group = mommy.make(models.Group)
+        data = {
+            'name': 'my group name',
+            'description': 'my group description',
+            'fore_color': '',
+            'background_color': '',
+            'on_contacts_list': True,
+        }
+        response = self.client.post(reverse('crm_edit_group', args=[group.id]), data=data)
+        self.assertEqual(302, response.status_code)
+        self.assertEqual(models.Group.objects.count(), 1)
+        group = models.Group.objects.get(id=group.id)
+        self.assertEqual(group.name, data['name'])
+        self.assertEqual(group.description, data['description'])
+        self.assertEqual(group.fore_color, data['fore_color'])
+        self.assertEqual(group.background_color, data['background_color'])
+        self.assertEqual(group.on_contacts_list, data['on_contacts_list'])
+
+    def test_edit_group_on_contacts_list_missing(self):
+        """it should modify the group"""
+        group = mommy.make(models.Group)
+        data = {
+            'name': 'my group name',
+            'description': 'my group description',
+            'fore_color': '',
+            'background_color': '',
+        }
+        response = self.client.post(reverse('crm_edit_group', args=[group.id]), data=data)
+        self.assertEqual(302, response.status_code)
+        self.assertEqual(models.Group.objects.count(), 1)
+        group = models.Group.objects.get(id=group.id)
+        self.assertEqual(group.name, data['name'])
+        self.assertEqual(group.description, data['description'])
+        self.assertEqual(group.fore_color, data['fore_color'])
+        self.assertEqual(group.background_color, data['background_color'])
+        self.assertEqual(group.on_contacts_list, False)
 
     def test_edit_group_add_members(self):
         """it should modify the group"""
@@ -890,9 +1006,9 @@ class SelectContactOrEntityGroupTestCase(BaseTestCase):
         response = self.client.post(reverse('crm_select_contact_or_entity'), data=data)
         self.assertEqual(200, response.status_code)
 
-        self.assertEqual(
-            response.content,
-            u'<script>$.colorbox.close(); if (addMember("{1}", {2})) {{addMemberToList({0});}};</script>'.format(
+        self.assertContains(
+            response,
+            '<script>$.colorbox.close(); if (addMember("{1}", {2})) {{addMemberToList({0});}};</script>'.format(
                 json_data, 'entity', entity.id
             )
         )
@@ -917,9 +1033,9 @@ class SelectContactOrEntityGroupTestCase(BaseTestCase):
         response = self.client.post(reverse('crm_select_contact_or_entity'), data=data)
         self.assertEqual(200, response.status_code)
 
-        self.assertEqual(
-            response.content,
-            u'<script>$.colorbox.close(); if (addMember("{1}", {2})) {{addMemberToList({0});}};</script>'.format(
+        self.assertContains(
+            response,
+            '<script>$.colorbox.close(); if (addMember("{1}", {2})) {{addMemberToList({0});}};</script>'.format(
                 json_data, 'contact', contact.id
             )
         )
@@ -1003,7 +1119,7 @@ class SelectContactOrEntityGroupTestCase(BaseTestCase):
 
         response = self.client.post(reverse('crm_select_contact_or_entity'), data=data)
         self.assertEqual(302, response.status_code)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_post_select_contact_not_allowed(self):
@@ -1020,5 +1136,5 @@ class SelectContactOrEntityGroupTestCase(BaseTestCase):
 
         response = self.client.post(reverse('crm_select_contact_or_entity'), data=data)
         self.assertEqual(302, response.status_code)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
\ No newline at end of file
