@@ -2,13 +2,14 @@
 """unit testing"""
 
 from datetime import datetime, timedelta
-import json
 
-from django.core.urlresolvers import reverse
+from django.urls import reverse
+from django.test.utils import override_settings
 
 from coop_cms.tests import BeautifulSoup
 from model_mommy import mommy
 
+from balafon.unit_tests import response_as_json
 from balafon.Crm import models
 from balafon.Crm.tests import BaseTestCase
 
@@ -26,7 +27,7 @@ class ActionArchiveTest(BaseTestCase):
         response = self.client.get(url)
 
         self.assertEqual(response.status_code, 302)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_view_monthly_action_non_staff(self):
@@ -38,7 +39,7 @@ class ActionArchiveTest(BaseTestCase):
         now = datetime.now()
         url = reverse('crm_actions_of_month', args=[now.year, now.month])
         response = self.client.get(url)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_view_monthly_action(self):
@@ -104,7 +105,7 @@ class ActionArchiveTest(BaseTestCase):
         response = self.client.get(url)
 
         self.assertEqual(response.status_code, 302)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_view_weekly_action_non_staff(self):
@@ -116,7 +117,7 @@ class ActionArchiveTest(BaseTestCase):
         now = datetime.now()
         url = reverse('crm_actions_of_week', args=[now.year, now.strftime("%W")])
         response = self.client.get(url)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_view_weekly_action(self):
@@ -183,7 +184,7 @@ class ActionArchiveTest(BaseTestCase):
         response = self.client.get(url)
 
         self.assertEqual(response.status_code, 302)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_view_dailly_action_non_staff(self):
@@ -195,7 +196,7 @@ class ActionArchiveTest(BaseTestCase):
         now = datetime.now()
         url = reverse('crm_actions_of_day', args=[now.year, now.month, now.day])
         response = self.client.get(url)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_view_daily_action(self):
@@ -280,7 +281,7 @@ class ActionArchiveTest(BaseTestCase):
 
         soup = BeautifulSoup(response.content)
         self.assertEqual(
-            [u"u{0}".format(y.id) for y in [user_joe, user_jack]],
+            ["u{0}".format(y.id) for y in [user_joe, user_jack]],
             [x["value"] for x in soup.select("select.action-filter option[selected=selected]")]
         )
 
@@ -311,7 +312,7 @@ class ActionArchiveTest(BaseTestCase):
 
         soup = BeautifulSoup(response.content)
         self.assertEqual(
-            sorted([u"t{0}".format(y.id) for y in [action_type1, action_type2]]),
+            sorted(["t{0}".format(y.id) for y in [action_type1, action_type2]]),
             sorted([x["value"] for x in soup.select("select.action-filter option[selected=selected]")])
         )
 
@@ -366,7 +367,7 @@ class ActionArchiveTest(BaseTestCase):
 
         soup = BeautifulSoup(response.content)
         self.assertEqual(
-            [u"t0"] + [u"t{0}".format(y.id) for y in [action_type1,]],
+            ["t0"] + ["t{0}".format(y.id) for y in [action_type1,]],
             [x["value"] for x in soup.select("select.action-filter option[selected=selected]")]
         )
 
@@ -441,7 +442,7 @@ class ActionArchiveTest(BaseTestCase):
 
         soup = BeautifulSoup(response.content)
         self.assertEqual(
-            [u"t{0}".format(action_type1.id)] + [u"u{0}".format(user_joe.id)],
+            ["t{0}".format(action_type1.id)] + ["u{0}".format(user_joe.id)],
             [x["value"] for x in soup.select("select.action-filter option[selected=selected]")]
         )
 
@@ -483,14 +484,14 @@ class ActionArchiveTest(BaseTestCase):
 
         soup = BeautifulSoup(response.content)
         self.assertEqual(
-            [u"t{0}".format(action_type1.id)] + [u"s{0}".format(action_status2.id)],
+            ["t{0}".format(action_type1.id)] + ["s{0}".format(action_status2.id)],
             [x["value"] for x in soup.select("select.action-filter option[selected=selected]")]
         )
         self.assertEqual(
             [
-                u"t0",
-                u"t{0}".format(action_type2.id), u"t{0}".format(action_type1.id),
-                u"s{0}".format(action_status2.id), u"s{0}".format(action_status1.id)
+                "t0",
+                "t{0}".format(action_type2.id), "t{0}".format(action_type1.id),
+                "s{0}".format(action_status2.id), "s{0}".format(action_status1.id)
             ],
             [x["value"] for x in soup.select("select.action-filter option")]
         )
@@ -528,11 +529,11 @@ class ActionArchiveTest(BaseTestCase):
 
         soup = BeautifulSoup(response.content)
         self.assertEqual(
-            [u"t{0}".format(action_type1.id)],
+            ["t{0}".format(action_type1.id)],
             [x["value"] for x in soup.select("select.action-filter option[selected=selected]")]
         )
         self.assertEqual(
-            [u"t0", u"t{0}".format(action_type1.id), u"t{0}".format(action_type2.id)],
+            ["t0", "t{0}".format(action_type1.id), "t{0}".format(action_type2.id)],
             [x["value"] for x in soup.select("select.action-filter option")]
         )
 
@@ -559,7 +560,36 @@ class ActionArchiveTest(BaseTestCase):
         subjects = [action.subject for action in actions]
         for subject in subjects:
             self.assertContains(response, subject)
-        pos = [response.content.find(subject) for subject in subjects]
+        content = response.content.decode('utf-8')
+        pos = [content.find(subject) for subject in subjects]
+        self.assertEqual(pos, list(sorted(pos)))
+
+    @override_settings(BALAFON_PLANNING_ORDERING=[(5, 'Custom', (('subject', )))])
+    def test_action_type_ordering_custom(self):
+        """view actions of the month incharge filter"""
+        now = datetime(2016, 10, 10, 12, 0)
+
+        action1 = mommy.make(models.Action, subject="#ACT1#", planned_date=now + timedelta(days=1))
+        action2 = mommy.make(models.Action, subject="#ACT2#", planned_date=now + timedelta(days=2))
+        action3 = mommy.make(models.Action, subject="#ACT3#", planned_date=now - timedelta(days=1))
+        action4 = mommy.make(models.Action, subject="#ACT4#", planned_date=now - timedelta(days=3))
+        action5 = mommy.make(models.Action, subject="#ACT5#", planned_date=now)
+
+        url = reverse(
+            'crm_actions_of_month', args=[now.year, now.month]
+        ) + "?filter=o5"
+        response = self.client.get(url, follow=True)
+        self.assertEqual(response.status_code, 200)
+
+        actions = [
+            action1, action2, action3, action4, action5
+        ]
+
+        subjects = [action.subject for action in actions]
+        for subject in subjects:
+            self.assertContains(response, subject)
+        content = response.content.decode('utf-8')
+        pos = [content.find(subject) for subject in subjects]
         self.assertEqual(pos, list(sorted(pos)))
 
     def test_action_type_ordering_desc(self):
@@ -585,7 +615,88 @@ class ActionArchiveTest(BaseTestCase):
         subjects = [action.subject for action in actions]
         for subject in subjects:
             self.assertContains(response, subject)
-        pos = [response.content.find(subject) for subject in subjects]
+        content = response.content.decode('utf-8')
+        pos = [content.find(subject) for subject in subjects]
+        self.assertEqual(pos, list(sorted(pos)))
+
+    def test_action_type_ordering_name(self):
+        """view actions of the month incharge filter"""
+        now = datetime(2016, 10, 10, 12, 0)
+
+        action1 = mommy.make(models.Action, subject="#ACT1#", planned_date=now + timedelta(days=1))
+        action2 = mommy.make(models.Action, subject="#ACT2#", planned_date=now + timedelta(days=2))
+        action3 = mommy.make(models.Action, subject="#ACT3#", planned_date=now - timedelta(days=1))
+        action4 = mommy.make(models.Action, subject="#ACT4#", planned_date=now - timedelta(days=3))
+        action5 = mommy.make(models.Action, subject="#ACT5#", planned_date=now)
+
+        contact1 = mommy.make(models.Contact, lastname="Dupond")
+        contact2 = mommy.make(models.Contact, lastname="Alain")
+        contact3 = contact2
+        contact4 = mommy.make(models.Contact, lastname="Bernard")
+        contact5 = mommy.make(models.Contact, lastname="Chausson")
+
+        actions = [action1, action2, action3, action4, action5]
+        contacts = [contact1, contact2, contact3, contact4, contact5]
+
+        for action, contact in zip(actions, contacts):
+            action.contacts.add(contact)
+            action.save()
+
+        url = reverse(
+            'crm_actions_of_month', args=[now.year, now.month]
+        ) + "?filter=o2"
+        response = self.client.get(url, follow=True)
+        self.assertEqual(response.status_code, 200)
+
+        actions = [
+            action3, action2, action4, action5, action1
+        ]
+
+        subjects = [action.subject for action in actions]
+        for subject in subjects:
+            self.assertContains(response, subject)
+        content = response.content.decode('utf-8')
+        pos = [content.find(subject) for subject in subjects]
+        self.assertEqual(pos, list(sorted(pos)))
+
+    def test_action_type_ordering_entity_name(self):
+        """view actions of the month incharge filter"""
+        now = datetime(2016, 10, 10, 12, 0)
+
+        action1 = mommy.make(models.Action, subject="#ACT1#", planned_date=now + timedelta(days=1))
+        action2 = mommy.make(models.Action, subject="#ACT2#", planned_date=now + timedelta(days=2))
+        action3 = mommy.make(models.Action, subject="#ACT3#", planned_date=now - timedelta(days=1))
+        action4 = mommy.make(models.Action, subject="#ACT4#", planned_date=now - timedelta(days=3))
+        action5 = mommy.make(models.Action, subject="#ACT5#", planned_date=now)
+
+        entity1 = mommy.make(models.Entity, name="Dupond")
+        entity2 = mommy.make(models.Entity, name="Alain")
+        entity3 = entity2
+        entity4 = mommy.make(models.Entity, name="Bernard")
+        entity5 = mommy.make(models.Entity, name="Chausson")
+
+        actions = [action1, action2, action3, action4, action5]
+        entities = [entity1, entity2, entity3, entity4, entity5]
+
+        for action, entity in zip(actions, entities):
+            action.entities.add(entity)
+            action.save()
+
+        url = reverse(
+            'crm_actions_of_month', args=[now.year, now.month]
+        ) + "?filter=o3"
+        response = self.client.get(url, follow=True)
+        self.assertEqual(response.status_code, 200)
+
+        actions = [
+            action3, action2, action4, action5, action1
+        ]
+
+        subjects = [action.subject for action in actions]
+        for subject in subjects:
+            self.assertContains(response, subject)
+        content = response.content.decode('utf-8')
+        pos = [content.find(subject) for subject in subjects]
         self.assertEqual(pos, list(sorted(pos)))
 
     def test_view_not_planned_action_anonymous(self):
@@ -597,7 +708,7 @@ class ActionArchiveTest(BaseTestCase):
         response = self.client.get(url)
 
         self.assertEqual(response.status_code, 302)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_view_not_planned_action_non_staff(self):
@@ -608,7 +719,7 @@ class ActionArchiveTest(BaseTestCase):
 
         url = reverse('crm_actions_not_planned')
         response = self.client.get(url)
-        login_url = reverse('django.contrib.auth.views.login')[3:]
+        login_url = reverse('login')[3:]
         self.assertTrue(response['Location'].find(login_url) >= 0)
 
     def test_view_not_planned_action(self):
@@ -665,7 +776,7 @@ class ActionArchiveTest(BaseTestCase):
 
         soup = BeautifulSoup(response.content)
         self.assertEqual(
-            [u"t{0}".format(action_type1.id)] + [u"u{0}".format(user_joe.id)],
+            ["t{0}".format(action_type1.id)] + ["u{0}".format(user_joe.id)],
             [x["value"] for x in soup.select("select.action-filter option[selected=selected]")]
         )
 
@@ -862,7 +973,7 @@ class GoToPlanningDateTest(BaseTestCase):
         response = self.client.post(url, data)
         self.assertEqual(200, response.status_code)
 
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
 
         self.assertEqual(resp_data['url'], reverse('crm_actions_of_day', args=[2016, 2, 14]) + '?filter=t2')
 
@@ -879,7 +990,7 @@ class GoToPlanningDateTest(BaseTestCase):
         response = self.client.post(url, data)
         self.assertEqual(200, response.status_code)
 
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
 
         self.assertEqual(resp_data['url'], reverse('crm_actions_of_day', args=[2016, 9, 14]) + '?filter=t2')
 
@@ -896,7 +1007,7 @@ class GoToPlanningDateTest(BaseTestCase):
         response = self.client.post(url, data)
         self.assertEqual(200, response.status_code)
 
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
 
         self.assertEqual(resp_data['url'], reverse('crm_actions_of_day', args=[2016, 12, 9]) + '?filter=t2')
 
@@ -913,7 +1024,7 @@ class GoToPlanningDateTest(BaseTestCase):
         response = self.client.post(url, data)
         self.assertEqual(200, response.status_code)
 
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
 
         self.assertEqual(resp_data['url'], reverse('crm_actions_of_month', args=[2016, 2]) + '?filter=t2')
 
@@ -930,7 +1041,7 @@ class GoToPlanningDateTest(BaseTestCase):
         response = self.client.post(url, data)
         self.assertEqual(200, response.status_code)
 
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
 
         self.assertEqual(resp_data['url'], reverse('crm_actions_of_week', args=[2016, 6]) + '?filter=t2')
 
@@ -947,7 +1058,7 @@ class GoToPlanningDateTest(BaseTestCase):
         response = self.client.post(url, data)
         self.assertEqual(200, response.status_code)
 
-        resp_data = json.loads(response.content)
+        resp_data = response_as_json(response)
 
         self.assertEqual(resp_data['url'], reverse('crm_actions_of_week', args=[2016, 6]))
 
