@@ -1,20 +1,23 @@
 # -*- coding: utf-8 -*-
 
+from datetime import datetime
+
 from django.core.management.base import BaseCommand
+
 from balafon.Emailing.models import Emailing
 from balafon.Emailing.utils import send_newsletter
-from datetime import datetime
 
 
 class Command(BaseCommand):
-    help = u"send all emailing marked ready for sending"
-    use_argparse = False
+    help = "send all emailing marked ready for sending"
 
-    def handle(self, *args, **options):
-        #look for emailing to be sent
+    def add_arguments(self, parser):
+        parser.add_argument('max_nb', type=int, default=20, nargs='?')
+
+    def handle(self, max_nb, *args, **options):
+        # look for emailing to be sent
         verbose = options.get('verbosity', 0)
         
-        max_nb = args[0] if len(args) > 0 else 20
         emailings = Emailing.objects.filter(
             status__in=(Emailing.STATUS_SCHEDULED, Emailing.STATUS_SENDING),
             scheduling_dt__lte=datetime.now()
@@ -27,15 +30,15 @@ class Command(BaseCommand):
             nb_sent = send_newsletter(emailing, max_nb)
             
             if verbose:
-                print nb_sent, "emails sent for emailing", emailing.id
+                print(nb_sent, "emails sent for emailing", emailing.id)
             
             total_sent += nb_sent
             
             if emailing.send_to.count() == 0:
                 if verbose:
-                    print "emailing", emailing.id, "done"
+                    print("emailing", emailing.id, "done")
                 emailing.status = Emailing.STATUS_SENT
                 emailing.save()
                 
             if total_sent > max_nb:
-                break #stop sending if we reached the allowed number
+                break  # stop sending if we reached the allowed number
