@@ -1,28 +1,34 @@
 # -*- coding: utf-8 -*-
 """test subscription"""
 
-from bs4 import BeautifulSoup
 from datetime import date
 
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core import mail
-from django.core.urlresolvers import reverse
-from django.test import TestCase
 from django.test.utils import override_settings
+from django.urls import reverse
 from django.utils.translation import activate
 
+from coop_cms.tests import BeautifulSoup
 from model_mommy import mommy
 
+from balafon.unit_tests import TestCase
 from balafon.Crm import models
 from balafon.Crm.signals import new_subscription
 
+
 @override_settings(BALAFON_EMAIL_SUBSCRIBE_ENABLED=True)
 class SubscribeTest(TestCase):
     """Subscription with just his email address"""
-    
+
+    @staticmethod
+    def email_as_text(email):
+        return email.message().as_string()
+
     def setUp(self):
         """before each test"""
+        super(SubscribeTest, self).setUp()
         self._lang = settings.LANGUAGES[0][0]
         activate(self._lang)
 
@@ -37,6 +43,7 @@ class SubscribeTest(TestCase):
         """after each test"""
         activate(self._lang)
         settings.BALAFON_DEFAULT_SUBSCRIPTION_TYPE = self._default_subscription_type
+        super(SubscribeTest, self).tearDown()
 
     @override_settings(LANGUAGES=(('en', 'English'), ('fr', 'French')))
     def test_view_subscription_language(self):
@@ -74,7 +81,7 @@ class SubscribeTest(TestCase):
         response = self.client.get(url)
         self.assertEqual(200, response.status_code)
         self.assertEqual(models.Contact.objects.count(), 0)
-        soup = BeautifulSoup(response.content, 'html.parser')
+        soup = BeautifulSoup(response.content)
         self.assertEqual(1, len(soup.select('form')))
         form = soup.select('form')[0]
         self.assertEqual(form['action'], url)
@@ -87,7 +94,7 @@ class SubscribeTest(TestCase):
         response = self.client.get(url)
         self.assertEqual(200, response.status_code)
         self.assertEqual(models.Contact.objects.count(), 0)
-        soup = BeautifulSoup(response.content, 'html.parser')
+        soup = BeautifulSoup(response.content)
         self.assertEqual(1, len(soup.select('form')))
         form = soup.select('form')[0]
         self.assertEqual(form['action'], url)
@@ -125,13 +132,13 @@ class SubscribeTest(TestCase):
         verification_email = mail.outbox[1]
         self.assertEqual(verification_email.to, [contact.email])
         url = reverse('emailing_email_verification', args=[contact.uuid])
-        email_content = verification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(verification_email)
         self.assertTrue(email_content.find(url) > 0)
         
         notification_email = mail.outbox[0]
         self.assertEqual(notification_email.to, [settings.BALAFON_NOTIFICATION_EMAIL])
-        #Not an Error message
-        self.assertTrue(notification_email.message().as_string().decode('utf-8').find("Error") < 0)
+        # Not an Error message
+        self.assertTrue(self.email_as_text(notification_email).find("Error") < 0)
         
         for subscription_type in (subscription_type1, subscription_type2):
             subscription = models.Subscription.objects.get(contact=contact, subscription_type=subscription_type)
@@ -212,13 +219,13 @@ class SubscribeTest(TestCase):
         verification_email = mail.outbox[1]
         self.assertEqual(verification_email.to, [contact.email])
         url = reverse('emailing_email_verification', args=[contact.uuid])
-        email_content = verification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(verification_email)
         self.assertTrue(email_content.find(url) > 0)
 
         notification_email = mail.outbox[0]
         self.assertEqual(notification_email.to, [settings.BALAFON_NOTIFICATION_EMAIL])
         #Not an Error message
-        self.assertTrue(notification_email.message().as_string().decode('utf-8').find("Error") < 0)
+        self.assertTrue(self.email_as_text(notification_email).find("Error") < 0)
 
         for subscription_type in (subscription_type1, ):
             subscription = models.Subscription.objects.get(contact=contact, subscription_type=subscription_type)
@@ -263,13 +270,13 @@ class SubscribeTest(TestCase):
         verification_email = mail.outbox[1]
         self.assertEqual(verification_email.to, [contact.email])
         url = reverse('emailing_email_verification', args=[contact.uuid])
-        email_content = verification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(verification_email)
         self.assertTrue(email_content.find(url) > 0)
 
         notification_email = mail.outbox[0]
         self.assertEqual(notification_email.to, [settings.BALAFON_NOTIFICATION_EMAIL])
         # Not an Error message
-        self.assertTrue(notification_email.message().as_string().decode('utf-8').find("Error") < 0)
+        self.assertTrue(self.email_as_text(notification_email).find("Error") < 0)
 
         for subscription_type in (subscription_type1, ):
             subscription = models.Subscription.objects.get(contact=contact, subscription_type=subscription_type)
@@ -315,13 +322,13 @@ class SubscribeTest(TestCase):
         verification_email = mail.outbox[1]
         self.assertEqual(verification_email.to, [contact.email])
         url = reverse('emailing_email_verification', args=[contact.uuid])
-        email_content = verification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(verification_email)
         self.assertTrue(email_content.find(url) > 0)
 
         notification_email = mail.outbox[0]
         self.assertEqual(notification_email.to, [settings.BALAFON_NOTIFICATION_EMAIL])
         #Not an Error message
-        self.assertTrue(notification_email.message().as_string().decode('utf-8').find("Error") < 0)
+        self.assertTrue(self.email_as_text(notification_email).find("Error") < 0)
 
         for subscription_type in (subscription_type2, ):
             subscription = models.Subscription.objects.get(contact=contact, subscription_type=subscription_type)
@@ -366,13 +373,13 @@ class SubscribeTest(TestCase):
         verification_email = mail.outbox[1]
         self.assertEqual(verification_email.to, [contact.email])
         url = reverse('emailing_email_verification', args=[contact.uuid])
-        email_content = verification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(verification_email)
         self.assertTrue(email_content.find(url) > 0)
 
         notification_email = mail.outbox[0]
         self.assertEqual(notification_email.to, [settings.BALAFON_NOTIFICATION_EMAIL])
         #Error message
-        self.assertTrue(notification_email.message().as_string().decode('utf-8').find("Error") >= 0)
+        self.assertTrue(self.email_as_text(notification_email).find("Error") >= 0)
 
         queryset = models.Subscription.objects.filter(contact=contact)
         self.assertEqual(0, queryset.count())
@@ -415,12 +422,12 @@ class SubscribeTest(TestCase):
         verification_email = mail.outbox[1]
         self.assertEqual(verification_email.to, [new_contact.email])
         url = reverse('emailing_email_verification', args=[new_contact.uuid])
-        email_content = verification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(verification_email)
         self.assertTrue(email_content.find(url) > 0)
 
         notification_email = mail.outbox[0]
         self.assertEqual(notification_email.to, [settings.BALAFON_NOTIFICATION_EMAIL])
-        email_content = notification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(notification_email)
         self.assertTrue(email_content.find(new_contact.fullname) > 0)
         self.assertTrue(email_content.find(new_contact.get_absolute_url()) > 0)
         self.assertTrue(email_content.find(existing_contact.get_absolute_url()) > 0)
@@ -482,12 +489,12 @@ class SubscribeTest(TestCase):
         verification_email = mail.outbox[1]
         self.assertEqual(verification_email.to, [new_contact.email])
         url = reverse('emailing_email_verification', args=[new_contact.uuid])
-        email_content = verification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(verification_email)
         self.assertTrue(email_content.find(url) > 0)
 
         notification_email = mail.outbox[0]
         self.assertEqual(notification_email.to, [settings.BALAFON_NOTIFICATION_EMAIL])
-        email_content = notification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(notification_email)
         self.assertTrue(email_content.find(new_contact.fullname) > 0)
         self.assertTrue(email_content.find(new_contact.get_absolute_url()) > 0)
         for existing_contact in (existing_contact1, existing_contact2, existing_contact3, existing_contact4):
@@ -553,13 +560,13 @@ class SubscribeTest(TestCase):
         verification_email = mail.outbox[1]
         self.assertEqual(verification_email.to, [contact.email])
         url = reverse('emailing_email_verification', args=[contact.uuid])
-        email_content = verification_email.message().as_string().decode('utf-8')
+        email_content = self.email_as_text(verification_email)
         self.assertTrue(email_content.find(url) > 0)
 
         notification_email = mail.outbox[0]
         self.assertEqual(notification_email.to, [settings.BALAFON_NOTIFICATION_EMAIL])
         # Not an Error message
-        self.assertTrue(notification_email.message().as_string().decode('utf-8').find("Error") < 0)
+        self.assertTrue(self.email_as_text(notification_email).find("Error") < 0)
 
         for subscription_type in (subscription_type1, subscription_type2):
             subscription = models.Subscription.objects.get(contact=contact, subscription_type=subscription_type)
