@@ -656,6 +656,99 @@ class SendEmailingTest(BaseTestCase):
             self.assertEqual(c.action_set.count(), 1)
             self.assertEqual(c.action_set.all()[0].subject, email.subject)
 
+    @override_settings(COOP_CMS_REPLY_TO="")
+    def test_send_newsletter_from_email_multi_lines(self):
+
+        entity = mommy.make(models.Entity, name="my corp")
+
+        names = ['alpha', 'beta', 'gamma']
+        contacts = [
+            mommy.make(
+                models.Contact, entity=entity,
+                email=name + '@toto.fr', lastname=name.capitalize()
+            ) for name in names
+        ]
+
+        content = '<h2>Hello #!-fullname-!#!</h2><p>Visit <a href="http://toto.fr">us</a>'
+        content += '<a href="mailto:me@me.fr">mailme</a><a href="#art1">internal link</a></p>'
+
+        newsletter_data = {
+            'subject': '<p>Balafon de retour<br />sur sc&egrave;ne\nen d&eacute;cembre !</p>',
+            'content': content,
+            'template': 'test/newsletter_contact.html'
+        }
+        newsletter = mommy.make(Newsletter, **newsletter_data)
+
+        site = Site.objects.get_current()
+        site.domain = "toto.fr"
+        site.save()
+
+        emailing = mommy.make(
+            Emailing,
+            newsletter=newsletter,
+            status=Emailing.STATUS_SCHEDULED,
+            scheduling_dt=datetime.now(),
+            sending_dt=None,
+            subscription_type=mommy.make(models.SubscriptionType, site=site),
+            from_email="abcd@defg.fr"
+        )
+
+        for contact in contacts:
+            emailing.send_to.add(contact)
+        emailing.save()
+
+        management.call_command('emailing_scheduler', verbosity=0)
+
+        emailing = Emailing.objects.get(id=emailing.id)
+
+        # check emailing status
+        self.assertEqual(emailing.status, Emailing.STATUS_SENT)
+        self.assertNotEqual(emailing.sending_dt, None)
+        self.assertEqual(emailing.send_to.count(), 0)
+        self.assertEqual(emailing.sent_to.count(), len(contacts))
+
+        self.assertEqual(len(mail.outbox), len(contacts))
+
+        outbox = list(mail.outbox)
+        outbox.sort(key=lambda e: e.to)
+        contacts.sort(key=lambda c: c.get_email)
+
+        for email, contact in zip(outbox, contacts):
+            viewonline_url = emailing.get_domain_url_prefix() + reverse(
+                'emailing_view_online', args=[emailing.id, contact.uuid]
+            )
+            unsubscribe_url = emailing.get_domain_url_prefix() + reverse(
+                'emailing_unregister', args=[emailing.id, contact.uuid]
+            )
+
+            self.assertEqual(email.to, [contact.get_email_address()])
+            self.assertEqual(email.from_email, emailing.from_email)
+            self.assertEqual(email.subject, 'Balafon de retour sur scène en décembre !')
+            # print email.body
+            self.assertEqual(
+                email.extra_headers['List-Unsubscribe'],
+                '<{0}>, <mailto:{1}?subject=unsubscribe>'.format(unsubscribe_url, emailing.from_email)
+            )
+            self.assertTrue(email.body.find(contact.fullname) >= 0)
+            self.assertTrue(email.alternatives[0][1], "text/html")
+            self.assertTrue(email.alternatives[0][0].find(contact.fullname) >= 0)
+            self.assertTrue(email.alternatives[0][0].find(viewonline_url) >= 0)
+            self.assertTrue(email.alternatives[0][0].find(unsubscribe_url) >= 0)
+
+            # Check mailto links are not magic
+            self.assertTrue(email.alternatives[0][0].find("mailto:me@me.fr") > 0)
+
+            # Check mailto links are not magic
+            self.assertTrue(email.alternatives[0][0].find("#art1") > 0)
+
+            # check magic links
+            self.assertTrue(MagicLink.objects.count() > 0)
+
+            # check an action has been created
+            c = models.Contact.objects.get(id=contact.id)
+            self.assertEqual(c.action_set.count(), 1)
+            self.assertEqual(c.action_set.all()[0].subject, email.subject)
+
     @override_settings(COOP_CMS_REPLY_TO="")
     def test_send_newsletter_check_unregister_name(self):
 
@@ -1040,6 +1133,36 @@ class SendEmailingTest(BaseTestCase):
 
         self.assertContains(response, long_link)
 
+    def test_click_view_long_links(self):
+        entity = mommy.make(models.Entity, name="my corp")
+        contact = mommy.make(
+            models.Contact, entity=entity,
+            email='toto@toto.fr', lastname='Azerty', firstname='Albert'
+        )
+        link = "http://toto.fr/{0}".format("abcde" * 40)
+        newsletter_data = {
+            'subject': 'This is the subject',
+            'content': '<p>Visit <a href="{0}">long link</a></p>'.format(link),
+            'template': 'test/newsletter_no_link.html'
+        }
+        newsletter = mommy.make(Newsletter, **newsletter_data)
+        emailing = mommy.make(Emailing, newsletter=newsletter)
+        emailing.sent_to.add(contact)
+        emailing.save()
+
+        url = reverse('emailing_view_online', args=[emailing.id, contact.uuid])
+        response = self.client.get(url)
+        self.assertEqual(200, response.status_code)
+
+        self.assertEqual(MagicLink.objects.count(), 1)
+
+        magic_link0 = MagicLink.objects.all()[0]
+        magic_link_url = reverse('emailing_view_link', args=[magic_link0.uuid, contact.uuid])
+        self.assertContains(response, magic_link_url)
+        self.assertEqual(magic_link0.url, link)
+        response = self.client.get(magic_link_url)
+        self.assertRedirects(response, link, fetch_redirect_response=False)
+
     def test_view_duplicate_links(self):
         entity = mommy.make(models.Entity, name="my corp")
         contact = mommy.make(
