@@ -10,20 +10,20 @@ from django.db.models import Q
 from django.conf import settings
 from django.contrib.sites.models import Site
 from django.core.exceptions import ValidationError
-from django.core.urlresolvers import reverse
 from django.forms.utils import flatatt
-from django.template import Context
 from django.template.loader import get_template
-from django.utils.encoding import smart_unicode
+from django.utils.encoding import smart_text
 from django.utils.html import escape
 from django.utils.translation import ugettext as _
+from django.urls import reverse
 
-import floppyforms as forms
+import floppyforms.__future__ as forms
 from coop_cms.bs_forms import Form as BsForm
 
 from balafon.fields import HidableModelMultipleChoiceField
 from balafon.Crm.models import Contact, Action, Group, Subscription, SubscriptionType
 from balafon.Crm.widgets import OpportunityAutoComplete
+from balafon.Crm.utils import sort_by_entity_callback
 from balafon.Search import models
 from balafon.Search.widgets import DatespanInput
 from balafon.Search.utils import get_date_bounds
@@ -49,7 +49,7 @@ class QuickSearchForm(BsForm):
 
 def get_search_forms():
     """cache the configured forms"""
-    global SEARCH_FORMS #pylint: disable=global-statement
+    global SEARCH_FORMS  #pylint: disable=global-statement
     if not SEARCH_FORMS:
         SEARCH_FORMS = load_from_name(settings.SEARCH_FORM_LIST)
     return SEARCH_FORMS
@@ -65,26 +65,27 @@ def get_field_form(field):
 
 
 class GroupedSelect(forms.Select):
-    """Buld select with all forms"""
+    """Build select with all forms"""
     def render(self, name, value, attrs=None, choices=(), *args, **kwargs):
         if value is None:
             value = ''
-        final_attrs = self.build_attrs(attrs, name=name)
-        output = [u'<select {0}>'.format(flatatt(final_attrs))] 
-        str_value = smart_unicode(value)
+        final_attrs = self.build_attrs(attrs)
+        final_attrs.update(dict(name=name))
+        output = [u'<select {0}>'.format(flatatt(final_attrs))]
+        str_value = smart_text(value)
         for group_label, group in self.choices: 
             if group_label:
                 # should belong to an optgroup
-                group_label = smart_unicode(group_label) 
+                group_label = smart_text(group_label)
                 output.append(u'<optgroup label="%s">' % escape(group_label)) 
             for key, value in group:
-                #build option html
-                option_value = smart_unicode(key)
+                # build option html
+                option_value = smart_text(key)
                 output.append(
                     u'<option value="{0}"{1}>{2}</option>'.format(
                         escape(option_value),
                         (option_value == str_value) and u' selected="selected"' or '',
-                        escape(smart_unicode(value))
+                        escape(smart_text(value))
                     )
                 )
             if group_label:
@@ -114,7 +115,7 @@ class GroupedChoiceField(forms.ChoiceField):
         value = super(GroupedChoiceField, self).clean(value)
         if value in (None, ''):
             value = u''
-        value = forms.util.smart_unicode(value)
+        value = smart_text(value)
         if value == u'':
             return value
         valid_values = []
@@ -179,7 +180,7 @@ class SearchForm(forms.Form):
         self._instance = instance
         self._save = save
         self.contacts_display = False
-        self.contains_refuse_newsletter = False
+        self.contains_refuse_newsletter = set()
         if instance:
             self.fields['name'].initial = instance.name
         if not data and instance:
@@ -243,7 +244,7 @@ class SearchForm(forms.Form):
             return unicode_str
             
         if str_value[0] == '[' and str_value[-1] == ']':
-            #remove [ and ]
+            # remove [ and ]
             values = str_value[1:-1]
             # get things separated by ', '
             values = values.split(", ")
@@ -267,7 +268,7 @@ class SearchForm(forms.Form):
         """validate name"""
         name = self.cleaned_data['name']
         if len(name) >= 100:
-            raise ValidationError(_(u"Too long"))
+            raise ValidationError(_("Too long"))
         if self._save:
             if name:
                 queryset = models.Search.objects.filter(name=name)
@@ -282,7 +283,7 @@ class SearchForm(forms.Form):
     
     def clean(self):
         """validate form"""
-        keys = self._forms.keys()
+        keys = list(self._forms.keys())
         keys.sort()
         cleaned_data = super(SearchForm, self).clean()
         for key in keys:
@@ -317,7 +318,7 @@ class SearchForm(forms.Form):
         """is full form valid?"""
         if not super(SearchForm, self).is_valid():
             return False
-        keys = self._forms.keys()
+        keys = list(self._forms.keys())
         keys.sort()
         for key in keys:
             for form in self._forms[key]:
@@ -327,28 +328,38 @@ class SearchForm(forms.Form):
     
     def _get_contacts(self):
         """get contacts"""
-        keys = self._forms.keys()
+        keys = list(self._forms.keys())
         keys.sort()
         contacts = set([])
         global_post_processors = []
-        self.contains_refuse_newsletter = False
-        
+        self.contains_refuse_newsletter = set()
+        has_sort_forms = False
+
         for key in keys:
             post_processors = []
             contacts_set = Contact.objects.all()
             actions_set = Action.objects.all()
+            exclude_actions_set = Action.objects.all()
             has_action_forms = False
+            has_exclude_action_forms = False
 
             if not ('secondary_contact' in [form.name for form in self._forms[key]]):
                 contacts_set = contacts_set.filter(main_contact=True)
             
             for form in self._forms[key]:
 
+                if form.is_sort_form:
+                    has_sort_forms = True
+
                 if not form.is_action_form:
                     contacts_set = form.get_queryset(contacts_set)
                 else:
-                    has_action_forms = True
-                    actions_set = form.get_queryset(actions_set)
+                    if form.is_exclude_action_form:
+                        has_exclude_action_forms = True
+                        exclude_actions_set = form.get_queryset(exclude_actions_set)
+                    else:
+                        has_action_forms = True
+                        actions_set = form.get_queryset(actions_set)
 
                 if hasattr(form, 'post_process'):
                     post_processors.append(form.post_process)
@@ -361,6 +372,11 @@ class SearchForm(forms.Form):
                     Q(action__in=actions_set) | Q(entity__action__in=actions_set)
                 ).distinct()
 
+            if has_exclude_action_forms:
+                contacts_set = contacts_set.exclude(
+                    Q(action__in=exclude_actions_set) | Q(entity__action__in=exclude_actions_set)
+                ).distinct()
+
             for post_processor in post_processors:
                 contacts_set = post_processor(contacts_set)
                 
@@ -369,17 +385,22 @@ class SearchForm(forms.Form):
         for global_post_processor in global_post_processors:
             contacts = global_post_processor(contacts)
 
+        # By default sort by entity
+        if not has_sort_forms:
+            contacts = sorted(contacts, key=sort_by_entity_callback)
+
         # Just for compatibility
-        queryset = SubscriptionType.objects.filter(site=Site.objects.get_current(), name=u'Newsletter')
+        current_site = Site.objects.get_current()
+        queryset = SubscriptionType.objects.filter(Q(site=current_site) | Q(allowed_on_sites=current_site))
         if queryset.count():
             for contact in contacts:
                 for subscription_type in queryset:
                     try:
                         if not contact.subscription_set.get(subscription_type=subscription_type).accept_subscription:
-                            self.contains_refuse_newsletter = True
+                            self.contains_refuse_newsletter.add(subscription_type.name)
                             break
                     except Subscription.DoesNotExist:
-                        self.contains_refuse_newsletter = True
+                        self.contains_refuse_newsletter.add(subscription_type.name)
                         break
                 
         return list(contacts)
@@ -401,7 +422,7 @@ class SearchForm(forms.Form):
         for contact in contacts:
             pass_filter = filter_func(contact)
             entity = contact.entity if contact else None
-            if entity and not entities.has_key(entity.id):
+            if entity and not entity.id in entities:
                 entities[entity.id] = (entity, [])
                 empty_entities[entity.id] = entity
             if pass_filter:
@@ -435,7 +456,7 @@ class SearchForm(forms.Form):
         for contact in contacts:
             if contact.get_email and (contact.id not in excluded_ids) and filter_func(contact):
                 if contact.firstname or contact.lastname:
-                    emails.append(u'"{1}" <{0}>'.format(contact.get_email, contact.fullname))
+                    emails.append('"{1}" <{0}>'.format(contact.get_email, contact.fullname))
                 else:
                     emails.append(contact.get_email)
         return emails
@@ -443,30 +464,30 @@ class SearchForm(forms.Form):
     def actions(self):
         """allowed actions"""
         form = FieldChoiceForm()
-        html_tpl = u"""{0}
-            <a class="btn btn-xs btn-default btn-yellow add-field" href="">
-            <span class="glyphicon glyphicon-filter"></span> {1}</a>
-            <a class="btn btn-xs btn-default add-block" href="">
-            <span class="glyphicon glyphicon-th-list"></span> {2}</a>
-            <a class="btn btn-xs btn-default duplicate-block" href="">
-            <span class="glyphicon glyphicon-share"></span> {5}</a>
+        html_tpl = """{0}
+            <a class="btn btn-xs btn-primary add-field" href="">
+            <i class="fas fa-filter"></i> {1}</a>
+            <a class="btn btn-xs btn-secondary add-block" href="">
+            <i class="fas fa-th-list"></i> {2}</a>
+            <a class="btn btn-xs btn-secondary duplicate-block" href="">
+            <i class="fas fa-share-square"></i> {5}</a>
             <a class="btn btn-xs btn-danger clear-block" href="">
-            <span class="glyphicon glyphicon-remove"></span> {3}</a>
+            <i class="fas fa-times"></i> {3}</a>
             <a class="btn btn-xs btn-danger remove-block" href="">
-            <span class="glyphicon glyphicon-trash"></span> {4}</a>"""
+            <i class="fas fa-trash-alt"></i> {4}</a>"""
 
         return html_tpl.format(
-            form.as_it_is(), _(u'Add filter'), _(u'Add block'), _(u'Clear'), _(u'Remove'), _(u'Duplicate')
+            form.as_it_is(), _('Add filter'), _('Add block'), _('Clear'), _('Remove'), _('Duplicate')
         )
     
     def as_html(self):
         """as html"""
-        keys = self._forms.keys()
+        keys = list(self._forms.keys())
         keys.sort()
-        html = u'<div>{0}</div>'.format(self.as_p())
+        html = '<div>{0}</div>'.format(self.as_p())
         if keys:
             for key in keys:
-                html_tpl = u'<div class="search-block" rel="{0}"><div class="actions">{1}</div><div class="fields">'
+                html_tpl = '<div class="search-block" rel="{0}"><div class="actions">{1}</div><div class="fields">'
                 html += html_tpl.format(key, self.actions())
                 for form in self._forms[key]:
                     html += form.as_it_is()
@@ -479,6 +500,8 @@ class SearchFieldForm(BsForm):
     contacts_display = False
     multi_values = False
     is_action_form = False
+    is_exclude_action_form = False
+    is_sort_form = False
 
     def __init__(self, block, count, data=None, *args, **kwargs):
         self.block = block
@@ -495,7 +518,7 @@ class SearchFieldForm(BsForm):
         
     def _get_field_name(self):
         """return field name"""
-        return self.block + '-_-' + self.name + '-_-' + unicode(self.count)
+        return self.block + '-_-' + self.name + '-_-' + str(self.count)
         
     def _add_field(self, field):
         """adda field"""
@@ -517,7 +540,7 @@ class SearchFieldForm(BsForm):
     def as_it_is(self):
         """return form html without any wrapper tag"""
         template = get_template("Search/_search_field_form.html")
-        return template.render(Context({"form": self}))
+        return template.render({"form": self})
     
     def get_queryset(self, queryset):
         """
@@ -571,7 +594,7 @@ class TwoDatesForm(SearchFieldForm):
         try:
             self._get_dates()
         except ValueError:
-            raise ValidationError(_(u"Two valid dates are required"))
+            raise ValidationError(_("Two valid dates are required"))
         return self.value
     
     def _get_dates(self):
@@ -608,7 +631,7 @@ class SearchActionBaseMixin(object):
         initial = kwargs.get('initial')
         initial_contacts = ''
         if initial and 'contacts' in initial:
-            initial_contacts = u';'.join([unicode(contact.id) for contact in initial['contacts']])
+            initial_contacts = ';'.join(['{0}'.format(contact.id) for contact in initial['contacts']])
             initial.pop('contacts')
         return initial_contacts
         
@@ -623,7 +646,7 @@ class SearchActionBaseMixin(object):
         contacts = Contact.objects.filter(id__in=ids)
         contact_by_ids = {}
         for contact in contacts:
-            contact_by_ids[unicode(contact.id)] = contact
+            contact_by_ids['{0}'.format(contact.id)] = contact
         ordered_contacts = []
         for contact_id in ids:
             ordered_contacts.append(contact_by_ids[contact_id])
@@ -644,7 +667,7 @@ class SubscribeContactsAdminForm(SearchActionForm):
     """This form is used for superuser forcing newsletter subscription"""
     subscription_type = forms.ChoiceField(required=True)
     subscribe = forms.BooleanField(
-        required=False, label=_(u'Subscribe'), help_text=_(u'It will subscribe/unsubscribe all selected contacts')
+        required=False, label=_('Subscribe'), help_text=_('It will subscribe/unsubscribe all selected contacts')
     )
 
     def __init__(self, *args, **kwargs):
@@ -658,7 +681,7 @@ class SubscribeContactsAdminForm(SearchActionForm):
         try:
             return SubscriptionType.objects.get(id=self.cleaned_data['subscription_type'])
         except SubscriptionType.DoesNotExist:
-            raise ValidationError(_(u'Unknown subscription type'))
+            raise ValidationError(_('Unknown subscription type'))
 
 
 class PdfTemplateForm(SearchActionForm):
@@ -672,18 +695,18 @@ class PdfTemplateForm(SearchActionForm):
             choices = settings.BALAFON_PDF_TEMPLATES
         else:
             choices = (
-                ('pdf/labels_24.html', _(u'etiquettes 24')),
-                ('pdf/labels_21.html', _(u'etiquettes 21')),
-                ('pdf/agipa_21.html', _(u'Agipa 21')),
-                ('pdf/labels_16.html', _(u'etiquettes 16')),
-                ('pdf/address_strip.html', _(u'bande adresse')),
+                ('pdf/labels_24.html', _('etiquettes 24')),
+                ('pdf/labels_21.html', _('etiquettes 21')),
+                ('pdf/agipa_21.html', _('Agipa 21')),
+                ('pdf/labels_16.html', _('etiquettes 16')),
+                ('pdf/address_strip.html', _('bande adresse')),
             )
         
         self.fields['template'] = forms.ChoiceField(
             choices=choices,
             required=True,
-            label=_(u'template'),
-            help_text=_(u'Select the type of document to generate')
+            label=_('template'),
+            help_text=_('Select the type of document to generate')
         )
         self.fields['template'].widget.attrs.update({'class': 'form-control'})
         
@@ -719,8 +742,8 @@ class PdfTemplateForm(SearchActionForm):
         
 class ActionForContactsForm(forms.ModelForm):
     """Create action for contacts"""
-    date = forms.DateField(label=_(u"planned date"), required=False, widget=forms.TextInput())
-    time = forms.TimeField(label=_(u"planned time"), required=False)
+    date = forms.DateField(label=_("planned date"), required=False, widget=forms.TextInput())
+    time = forms.TimeField(label=_("planned time"), required=False)
     contacts = forms.CharField(widget=forms.HiddenInput())
     
     class Meta:
@@ -734,13 +757,13 @@ class ActionForContactsForm(forms.ModelForm):
         initial = kwargs.get('initial')
         initial_contacts = ''
         if initial and 'contacts' in initial:
-            initial_contacts = u';'.join([unicode(c.id) for c in initial['contacts']])
+            initial_contacts = ';'.join(['{0}'.format(c.id) for c in initial['contacts']])
             initial.pop('contacts')
         super(ActionForContactsForm, self).__init__(*args, **kwargs)
         if initial_contacts:
             self.fields['contacts'].initial = initial_contacts
         self.fields['opportunity'].widget = OpportunityAutoComplete(
-            attrs={'placeholder': _(u'Enter the name of an opportunity'), 'size': '80', 'class': 'colorbox'}
+            attrs={'placeholder': _('Enter the name of an opportunity'), 'size': '80', 'class': 'colorbox'}
         )
         
     def get_contacts(self):
@@ -762,10 +785,10 @@ class GroupForContactsForm(forms.Form):
     contacts = forms.CharField(widget=forms.HiddenInput())
     groups = HidableModelMultipleChoiceField(queryset=Group.objects.all())
     on_contact = forms.BooleanField(
-        label=_(u"Group on contact"),
+        label=_("Group on contact"),
         required=False,
         initial=True,
-        help_text=_(u"Define if the group is added on the contact itself or on his entity")
+        help_text=_("Define if the group is added on the contact itself or on his entity")
     )
     
     class Media:
@@ -781,7 +804,7 @@ class GroupForContactsForm(forms.Form):
         initial = kwargs.get('initial')
         initial_contacts = ''
         if initial and 'contacts' in initial:
-            initial_contacts = u';'.join([unicode(contact.id) for contact in initial['contacts']])
+            initial_contacts = ';'.join(['{0}'.format(contact.id) for contact in initial['contacts']])
             initial.pop('contacts')
         super(GroupForContactsForm, self).__init__(*args, **kwargs)
         if initial_contacts:
@@ -789,7 +812,7 @@ class GroupForContactsForm(forms.Form):
     
         self.fields['groups'].widget.attrs = {
             'class': 'chzn-select',
-            'data-placeholder': _(u'Select groups'),
+            'data-placeholder': _('Select groups'),
             'style': "width:350px;"
         }
         self.fields['groups'].help_text = ''
@@ -803,7 +826,7 @@ class GroupForContactsForm(forms.Form):
 class SearchNameForm(forms.Form):
     """Save search form"""
     search_id = forms.IntegerField(required=False, widget=forms.HiddenInput())
-    name = forms.CharField(required=True, label=_(u"Name"))
+    name = forms.CharField(required=True, label=_("Name"))
     search_fields = forms.CharField(required=True, widget=forms.HiddenInput())
     
     def clean_name(self):
@@ -812,13 +835,13 @@ class SearchNameForm(forms.Form):
         
         name = self.cleaned_data["name"]
         if not name:
-            raise ValidationError(_(u"This field is required"))
+            raise ValidationError(_("This field is required"))
         
         queryset = models.Search.objects.filter(name=name)
         if search_id:
             queryset = queryset.exclude(id=search_id)
         if queryset.count() > 0:
-            raise ValidationError(_(u"This name is already used"))
+            raise ValidationError(_("This name is already used"))
         
         if search_id:
             search = models.Search.objects.get(id=search_id)
