@@ -8,12 +8,13 @@ from django.db.models import Q
 from django.contrib import messages
 from django.conf import settings
 from django.core.exceptions import PermissionDenied
-from django.core.urlresolvers import reverse
 from django.contrib.auth.decorators import user_passes_test
 from django.http import Http404, HttpResponse, HttpResponseRedirect
-from django.shortcuts import render_to_response, get_object_or_404, render
-from django.template import RequestContext, Context, Template
+from django.shortcuts import get_object_or_404, render
+from django.template import Template, Context
+from django.urls import reverse
 from django.utils.translation import ugettext as _
+from django.views.decorators.csrf import csrf_exempt
 
 from colorbox.decorators import popup_redirect, popup_close
 from coop_cms.models import Newsletter
@@ -36,68 +37,70 @@ from balafon.Search.forms import (
 def filter_icontains_unaccent(queryset, field, text):
     if crm_settings.is_unaccent_filter_supported():
         queryset = queryset.extra(
-            where=[u"UPPER(unaccent("+field+")) LIKE UPPER(unaccent(%s))"],
-            params=[u"%{0}%".format(text)]
+            where=["UPPER(unaccent("+field+")) LIKE UPPER(unaccent(%s))"],
+            params=["%{0}%".format(text)]
         )
         return list(queryset)
     return list(queryset.filter(**{field+"__icontains": text}))
 
 
+@csrf_exempt
 @user_passes_test(can_access)
 def quick_search(request):
-    if request.method == "POST":
-        form = QuickSearchForm(request.POST)
-        if form.is_valid():
-            text = form.cleaned_data["text"]
-            
-            queryset = Entity.objects.filter(is_single_contact=False)
-            entities_by_name = filter_icontains_unaccent(queryset, 'name', text)
-            
-            queryset = Contact.objects.all()#.filter(has_left=False)
-            contacts_by_name = filter_icontains_unaccent(queryset, 'lastname', text)
-            
-            for entity in entities_by_name:
-                setattr(entity, 'is_entity', True)
-                for contact in entity.contact_set.all():
-                    try:
-                        # avoid duplicates
-                        contacts_by_name.remove(contact)
-                    except ValueError:
-                        pass
-            contacts = entities_by_name + contacts_by_name
-            contacts.sort(key=lambda x: getattr(x, 'name', getattr(x, 'lastname', '')))
-            
-            queryset = Group.objects.all()
-            groups_by_name = filter_icontains_unaccent(queryset, 'name', text)
-            
-            contacts_by_email = Contact.objects.filter(
-                Q(email__icontains=text) | (Q(email="") & Q(entity__email__icontains=text)))
-            
-            cities_by_name = []
-            for city in City.objects.filter(name__icontains=text):
-                entities_count, contacts_count = city.contact_set.count(), city.entity_set.count()
-                if entities_count + contacts_count:
-                    cities_by_name.append((city, entities_count, contacts_count))
-            
-            contacts_by_phone = list(Contact.objects.filter(Q(mobile__icontains=text) | Q(phone__icontains=text)))
-            contacts_by_phone += list(Entity.objects.filter(phone__icontains=text))
-            
-            context_dict = {
-                'contacts_by_phone': contacts_by_phone,
-                'cities_by_name': cities_by_name,
-                'text': text,
-                'contacts_by_email': contacts_by_email,
-                'contacts': contacts,
-                'groups_by_name': groups_by_name,
-            }
-                
-            return render_to_response(
-                'Search/quicksearch_results.html',
-                context_dict,
-                context_instance=RequestContext(request)
-            )
+    form = QuickSearchForm(request.GET)
+    if form.is_valid():
+        text = form.cleaned_data["text"]
+
+        queryset = Entity.objects.filter(is_single_contact=False)
+        entities_by_name = filter_icontains_unaccent(queryset, 'name', text)
+
+        queryset = Contact.objects.all()#.filter(has_left=False)
+        contacts_by_name = filter_icontains_unaccent(queryset, 'lastname', text)
+
+        for entity in entities_by_name:
+            setattr(entity, 'is_entity', True)
+            for contact in entity.contact_set.all():
+                try:
+                    # avoid duplicates
+                    contacts_by_name.remove(contact)
+                except ValueError:
+                    pass
+        contacts = entities_by_name + contacts_by_name
+        contacts.sort(key=lambda x: getattr(x, 'name', getattr(x, 'lastname', '')))
+
+        queryset = Group.objects.all()
+        groups_by_name = filter_icontains_unaccent(queryset, 'name', text)
+
+        contacts_by_email = Contact.objects.filter(
+            Q(email__icontains=text) | (Q(email="") & Q(entity__email__icontains=text)))
+
+        cities_by_name = []
+        for city in City.objects.filter(name__icontains=text):
+            entities_count, contacts_count = city.contact_set.count(), city.entity_set.count()
+            if entities_count + contacts_count:
+                cities_by_name.append((city, entities_count, contacts_count))
+
+        contacts_by_phone = list(Contact.objects.filter(Q(mobile__icontains=text) | Q(phone__icontains=text)))
+        contacts_by_phone += list(Entity.objects.filter(phone__icontains=text))
+
+        context_dict = {
+            'contacts_by_phone': contacts_by_phone,
+            'cities_by_name': cities_by_name,
+            'text': text,
+            'contacts_by_email': contacts_by_email,
+            'contacts': contacts,
+            'groups_by_name': groups_by_name,
+        }
     else:
-        raise Http404
+        context_dict = {
+            'text': request.GET.get('text', '') or '',
+        }
+
+    return render(
+        request,
+        'Search/quicksearch_results.html',
+        context_dict
+    )
 
 
 @user_passes_test(can_access)
@@ -106,7 +109,7 @@ def search(request, search_id=0, group_id=0, opportunity_id=0, city_id=0):
     results = []
     search_obj = None
     field_choice_form = FieldChoiceForm()
-    contains_refuse_newsletter = False
+    contains_refuse_newsletter = []
     data = None
     contacts_count = 0
     has_empty_entities = False
@@ -132,14 +135,14 @@ def search(request, search_id=0, group_id=0, opportunity_id=0, city_id=0):
             
             if not contacts_display:
                 results, contacts_count, has_empty_entities = search_form.get_contacts_by_entity()
-                contains_refuse_newsletter = search_form.contains_refuse_newsletter
+                contains_refuse_newsletter = list(search_form.contains_refuse_newsletter)
             else:
                 results = search_form.get_contacts()
                 contacts_count, has_empty_entities = len(results), False
-                contains_refuse_newsletter = search_form.contains_refuse_newsletter
+                contains_refuse_newsletter = list(search_form.contains_refuse_newsletter)
             
             if not results:
-                message = _(u'Sorry, no results found')
+                message = _('Sorry, no results found')
     else:
         search_obj = get_object_or_404(Search, id=search_id) if search_id else None
         search_form = SearchForm(instance=search_obj)
@@ -148,7 +151,8 @@ def search(request, search_id=0, group_id=0, opportunity_id=0, city_id=0):
 
     page_obj = paginate(request, results, getattr(settings, 'BALAFON_SEARCH_NB_IN_PAGE', None) or 50)
 
-    return render_to_response(
+    return render(
+        request,
         'Search/search.html',
         {
             'page_obj': page_obj,
@@ -165,8 +169,7 @@ def search(request, search_id=0, group_id=0, opportunity_id=0, city_id=0):
             'opportunity': opportunity,
             'city': city,
             'contacts_display': contacts_display,
-        },
-        context_instance=RequestContext(request)
+        }
     )
 
 
@@ -198,13 +201,13 @@ def save_search(request, search_id):
             initial = {'search_id': 0}
         form = SearchNameForm(initial=initial)
     
-    return render_to_response(
+    return render(
+        request,
         'Search/search_name.html',
         {
             'form': form,
             'search_id': search_id,
-        },
-        context_instance=RequestContext(request)
+        }
     )
 
 
@@ -217,8 +220,11 @@ def get_field(request, name):
     try:
         form_class = get_field_form(name)
         the_template = Template('{{form.as_it_is}}')
-        the_context = Context({'form': form_class(block, count)})
-        return HttpResponse(json.dumps({'form': the_template.render(the_context)}), content_type="application/json")
+        the_context = {'form': form_class(block, count)}
+        return HttpResponse(
+            json.dumps({'form': the_template.render(Context(the_context))}),
+            content_type="application/json"
+        )
     except KeyError:
         raise Http404
     except Exception as msg:
@@ -249,18 +255,18 @@ def mailto_contacts(request, bcc):
                                 email_groups.append(emails[index_from:])
                                 break
                             index_from = index_to
-                        return render_to_response(
+                        return render(
+                            request,
                             'Search/mailto_groups.html',
-                            {'bcc': int(bcc), 'email_groups': email_groups, 'nb_limit': nb_limit},
-                            context_instance=RequestContext(request)
+                            {'bcc': int(bcc), 'email_groups': email_groups, 'nb_limit': nb_limit}
                         )
                 else:
-                    mailto = u'mailto:'
+                    mailto = 'mailto:'
                     if int(bcc): mailto += '?bcc='
                     mailto += ','.join(emails)
                     return HttpResponseRedirectMailtoAllowed(mailto)
             else:
-                return HttpResponse(_(u'Mailto: Error, no emails defined'), content_type='text/plain')
+                return HttpResponse(_('Mailto: Error, no emails defined'), content_type='text/plain')
     raise Http404
 
 
@@ -269,13 +275,13 @@ def view_search_list(request):
     searches = Search.objects.all()
     page_obj = paginate(request, searches, 50)
 
-    return render_to_response(
+    return render(
+        request,
         'Search/search_list.html',
         {
             'searches': list(page_obj),
             'page_obj': page_obj,
-        },
-        context_instance=RequestContext(request)
+        }
     )
 
 
@@ -312,20 +318,20 @@ def create_emailing(request):
                     
                     return HttpResponseRedirect(newsletter.get_absolute_url())
                 else:
-                    return render_to_response(
+                    return render(
+                        request,
                         'Search/create_action_for_contacts.html',
-                        {'form': form},
-                        context_instance=RequestContext(request)
+                        {'form': form}
                     )
             else:
                 search_form = SearchForm(request.POST)
                 if search_form.is_valid():
                     contacts = search_form.get_contacts()
                     form = NewEmailingForm(initial={'contacts': contacts})
-                    return render_to_response(
+                    return render(
+                        request,
                         'Search/new_emailing.html',
-                        {'form': form},
-                        context_instance=RequestContext(request)
+                        {'form': form}
                     )
     except Exception as msg:
         logger.exception("create_emailing")
@@ -341,7 +347,7 @@ def export_contacts_as_excel(request):
             contacts = search_form.get_contacts()
             if not search_form.contacts_display:
                 # if the form already has a sort criteria: don't sort again
-                contacts.sort(key=lambda x: u"{0}-{1}-{2}".format(x.entity, x.lastname, x.firstname))
+                contacts.sort(key=lambda x: "{0}-{1}-{2}".format(x.entity, x.lastname, x.firstname))
             
             # create the excel document
             workbook = xlwt.Workbook()
@@ -357,8 +363,8 @@ def export_contacts_as_excel(request):
             header_style = xlwt.easyxf('font: bold 1; pattern: pattern solid, fore-colour gray25;')
             # create a map of verbose name for each field
             field_dict = dict([(field.name, _(field.verbose_name).capitalize()) for field in Contact._meta.fields])
-            field_dict['foreign_country'] = _(u"Country")
-            field_dict['entity_name'] = _(u"Entity")
+            field_dict['foreign_country'] = _("Country")
+            field_dict['entity_name'] = _("Entity")
             
             # Add custom fields
             for cf in CustomField.objects.filter(export_order__gt=0).order_by('export_order'):
@@ -384,20 +390,20 @@ def export_contacts_as_excel(request):
                     field = getattr(contact, field_name)
 
                     if field_name == 'role':
-                        field = u", ".join([r.name for r in field.all()])
+                        field = ", ".join([r.name for r in field.all()])
 
                     elif callable(field):
                         field = field()
 
                     if field:
-                        worksheet.write(index+1, index2, unicode(field), style)
+                        worksheet.write(index+1, index2, '{0}'.format(field), style)
 
             response = HttpResponse(content_type='application/vnd.ms-excel')
             response['Content-Disposition'] = 'attachment; filename={0}.xls'.format('balafon')
             workbook.save(response)
             return response
         else:
-            logger.error(unicode(search_form.errors))
+            logger.error('{0}'.format(search_form.errors))
     raise Http404
 
 
@@ -422,14 +428,14 @@ def create_action_for_contacts(request):
                 messages.add_message(
                     request,
                     messages.SUCCESS,
-                    _(u"{0} actions have been created".format(len(contacts)))
+                    _("{0} actions have been created".format(len(contacts)))
                 )
                 return HttpResponseRedirect(reverse('crm_board_panel'))
             else:
-                return render_to_response(
+                return render(
+                    request,
                     'Search/create_action_for_contacts.html',
-                    {'form': form},
-                    context_instance=RequestContext(request)
+                    {'form': form}
                 )
         else:
             search_form = SearchForm(request.POST)
@@ -437,19 +443,19 @@ def create_action_for_contacts(request):
                 contacts = search_form.get_contacts()
                 if contacts:
                     form = ActionForContactsForm(initial={'contacts': contacts})
-                    return render_to_response(
+                    return render(
+                        request,
                         'Search/create_action_for_contacts.html',
-                        {'form': form},
-                        context_instance=RequestContext(request)
+                        {'form': form}
                     )
                 else:
-                    return render_to_response(
+                    return render(
+                        request,
                         'balafon/message_dialog.html',
                         {
                             'title': _('Create action for contacts'),
-                            'message': _(u'The search results contains no contacts')
-                        },
-                        context_instance=RequestContext(request)
+                            'message': _('The search results contains no contacts')
+                        }
                     )
     raise Http404
 
@@ -470,20 +476,24 @@ def add_contacts_to_group(request):
                             for c in contacts:
                                 g.contacts.add(c)
                             g.save()
-                        messages.add_message(request, messages.SUCCESS, _(u"{0} contacts have been added to groups".format(len(contacts))))
+                        messages.add_message(
+                            request, messages.SUCCESS, _("{0} contacts have been added to groups".format(len(contacts)))
+                        )
                     else:
                         entities = set([c.entity for c in contacts])
                         for g in groups:
                             for entity in entities:
                                 g.entities.add(entity)
                             g.save()
-                        messages.add_message(request, messages.SUCCESS, _(u"{0} entities have been added to groups".format(len(entities))))
+                        messages.add_message(
+                            request, messages.SUCCESS, _("{0} entities have been added to groups".format(len(entities)))
+                        )
                     return HttpResponseRedirect(reverse('crm_board_panel'))
                 else:
-                    return render_to_response(
+                    return render(
+                        request,
                         'Search/add_contacts_to_group.html',
-                        {'form': form},
-                        context_instance=RequestContext(request)
+                        {'form': form}
                     )
             else:
                 search_form = SearchForm(request.POST)
@@ -491,19 +501,19 @@ def add_contacts_to_group(request):
                     contacts = search_form.get_contacts()
                     if contacts:
                         form = GroupForContactsForm(initial={'contacts': contacts})
-                        return render_to_response(
+                        return render(
+                            request,
                             'Search/add_contacts_to_group.html',
-                            {'form': form},
-                            context_instance=RequestContext(request)
+                            {'form': form}
                         )
                     else:
-                        return render_to_response(
+                        return render(
+                            request,
                             'balafon/message_dialog.html',
                             {
                                 'title': _('Add contacts to group'),
-                                'message': _(u'The search results contains no contacts')
-                            },
-                            context_instance=RequestContext(request)
+                                'message': _('The search results contains no contacts')
+                            }
                         )
     except Exception as msg:
         logger.exception("add_contacts_to_group")
@@ -552,13 +562,13 @@ def subscribe_contacts_admin(request):
                         messages.add_message(
                             request,
                             messages.SUCCESS,
-                            _(u"{0} contacts have subscribe to the newsletter".format(nb_contacts))
+                            _("{0} contacts have subscribe to the newsletter".format(nb_contacts))
                         )
                     else:
                         messages.add_message(
                             request,
                             messages.SUCCESS,
-                            _(u"{0} contacts have unsubscribe to the newsletter".format(nb_contacts))
+                            _("{0} contacts have unsubscribe to the newsletter".format(nb_contacts))
                         )
 
                     return None  # popup_close will return js code to close the popup
@@ -585,7 +595,7 @@ def subscribe_contacts_admin(request):
                             'balafon/message_dialog.html',
                             {
                                 'title': _('Subscribe contacts admin'),
-                                'message': _(u'The search results contains no contacts')
+                                'message': _('The search results contains no contacts')
                             }
                         )
     except Exception:
@@ -628,10 +638,10 @@ def export_to_pdf(request):
                     return pdf_view.render_to_response(context)
 
                 else:
-                    return render_to_response(
+                    return render(
+                        request,
                         'Search/export_to_pdf.html',
-                        {'form': form},
-                        context_instance=RequestContext(request)
+                        {'form': form}
                     )
             else:
                 search_form = SearchForm(request.POST)
@@ -639,10 +649,10 @@ def export_to_pdf(request):
                     contacts = search_form.get_contacts()
                     search_dict = json.dumps(search_form.serialize())
                     form = PdfTemplateForm(initial={'contacts': contacts, 'search_dict': search_dict})
-                    return render_to_response(
+                    return render(
+                        request,
                         'Search/export_to_pdf.html',
-                        {'form': form},
-                        context_instance=RequestContext(request)
+                        {'form': form}
                     )
     except Exception as msg:
         logger.exception("export_to_pdf")
