@@ -16,12 +16,12 @@ from balafon.Crm.models import Action, ActionType
 from balafon.Profile.models import ContactProfile
 from balafon.Store.models import (
     Favorite, SaleItem, StoreItem, StoreItemCategory, StoreItemTag, StoreManagementActionType, DeliveryPoint,
-    SaleAnalysisCode
+    SaleAnalysisCode, Voucher
 )
 from balafon.Store import settings
 from balafon.Store.api import serializers
-from balafon.Store.settings import get_cart_type_name, get_cart_processed_callback
-from balafon.Store.utils import notify_cart_to_admin, confirm_cart_to_user, logger
+from balafon.Store.settings import get_cart_type_name, get_cart_processed_callback, get_notify_cart_callback
+from balafon.Store.utils import notify_cart_to_admin, confirm_cart_to_user
 
 
 class CanAccessStorePermission(permissions.BasePermission):
@@ -127,6 +127,37 @@ class StoreItemTagViewSet(viewsets.ModelViewSet):
     permission_classes = get_public_api_permissions()
 
 
+class VoucherView(APIView):
+    """post a cart"""
+    permission_classes = (permissions.IsAuthenticated,)
+
+    def post(self, request):
+        """receive a new cart"""
+        voucher_serializer = serializers.VoucherSerializer(data=request.data)
+        voucher_serializer.is_valid(raise_exception=True)
+        voucher_code = voucher_serializer.validated_data['voucher_code']
+        voucher = Voucher.get_active_voucher(voucher_code)
+        voucher_discount_vat_incl = 0
+        for item in voucher_serializer.validated_data['items']:
+            quantity = Decimal('{0}'.format(item['quantity']))
+            try:
+                store_item = StoreItem.objects.get(id=item['id'])
+            except StoreItem.DoesNotExist:
+                # ignore if not existing
+                continue
+
+            if voucher:
+                discount = store_item.vat_incl_price() * voucher.rate / 100
+                voucher_discount_vat_incl += quantity * discount
+
+        discount_data = {
+            'voucher_code': voucher_code,
+            'label': voucher.label if voucher else '',
+            'discount': voucher_discount_vat_incl,
+        }
+        return Response(discount_data)
+
+
 class CartView(APIView):
     """post a cart"""
     permission_classes = (permissions.IsAuthenticated,)
@@ -137,6 +168,11 @@ class CartView(APIView):
         cart_serializer = serializers.CartSerializer(data=request.data)
         if cart_serializer.is_valid():
 
+            discounts = {}
+            vat_rates = {}
+            voucher_code = cart_serializer.validated_data.get('voucher_code', '')
+            voucher = Voucher.get_active_voucher(voucher_code)
+
             # Get Contact
             try:
                 profile = ContactProfile.objects.get(user=request.user)
@@ -183,6 +219,7 @@ class CartView(APIView):
             warnings = []
             is_empty = True
             # for each line add a sale item
+            counter = 0
             for index, item in enumerate(cart_serializer.validated_data['items']):
 
                 quantity = Decimal('{0}'.format(item['quantity']))
@@ -214,6 +251,30 @@ class CartView(APIView):
                         text=store_item.name,
                         order_index=index + 1
                     )
+                    counter = index
+
+                    # calcule s'il y a une réduction Code Promo
+                    # Crée une ligne réduction pour ce code
+                    if voucher:
+                        discount = store_item.pre_tax_price * voucher.rate / 100
+                        vat_id = store_item.vat_rate.id if store_item.vat_rate else 0
+                        if vat_id not in discounts:
+                            vat_rates[vat_id] = store_item.vat_rate
+                            discounts[vat_id] = 0
+                        discounts[vat_id] += discount * quantity
+
+            for discount_vat, discount_value in discounts.items():
+                counter += 1
+                SaleItem.objects.create(
+                    sale=action.sale,
+                    quantity=1,
+                    item=None,
+                    vat_rate=vat_rates[discount_vat],
+                    pre_tax_price=-discount_value,
+                    text=voucher.label,
+                    order_index=counter,
+                    is_discount=True
+                )
 
             # Done
             if is_empty:
@@ -232,11 +293,16 @@ class CartView(APIView):
                 if on_cart_processed:
                     on_cart_processed(action)
 
-                confirm_cart_to_user(profile, action)
-                notify_cart_to_admin(profile, action)
+                notify_cart_callback = get_notify_cart_callback()
+                if notify_cart_callback is None:
+                    confirm_cart_to_user(profile, action)
+                    notify_cart_to_admin(profile, action)
+                else:
+                    notify_cart_callback(profile, action)
 
                 return Response({
                     'ok': True,
+                    'action': action.id,
                     'warnings': warnings,
                     'deliveryDate': action.planned_date,
                     'deliveryPlace': action.sale.delivery_point.name,
