@@ -1,7 +1,7 @@
 # -*- coding: utf-8 -*-
 """models"""
 
-from datetime import datetime
+from datetime import date, datetime
 from decimal import Decimal, InvalidOperation
 import os.path
 from six import string_types
@@ -34,6 +34,14 @@ class StoreManagementActionType(models.Model):
         default='', blank=True, max_length=100, verbose_name=_('template name'),
         help_text=_('Set the name of a custom template for commercial document')
     )
+    header_template_name = models.CharField(
+        default='', blank=True, max_length=100, verbose_name=_('header template name'),
+        help_text=_('Set the name of a custom template for commercial document header')
+    )
+    footer_template_name = models.CharField(
+        default='', blank=True, max_length=100, verbose_name=_('footer template name'),
+        help_text=_('Set the name of a custom template for commercial document footer')
+    )
     show_amount_as_pre_tax = models.BooleanField(
         default=True,
         verbose_name=_('Show amount as pre-tax'),
@@ -300,6 +308,40 @@ class Discount(models.Model):
         return None
 
 
+class Voucher(models.Model):
+    """Discount voucher"""
+    code = models.CharField(max_length=100, verbose_name=_('code'))
+    start_date = models.DateField(verbose_name=_('start date'))
+    end_date = models.DateField(verbose_name=_('end date'))
+    rate = models.DecimalField(
+        default=0, max_digits=4, decimal_places=2, verbose_name=_('rate')
+    )
+    active = models.BooleanField(default=False, verbose_name=_('active'))
+
+    class Meta:
+        verbose_name = _("Voucher")
+        verbose_name_plural = _("Vouchers")
+        ordering = ['-start_date', 'end_date']
+
+    def __str__(self):
+        return self.code
+
+    @classmethod
+    def get_active_voucher(cls, code):
+        today = date.today()
+        voucher = cls.objects.filter(
+            code=code,
+            active=True,
+            start_date__lte=today,
+            end_date__gte=today
+        ).first()
+        return voucher
+
+    @property
+    def label(self):
+        return ugettext('Voucher {0} : Discount {1}%').format(self.code, self.rate.normalize())
+
+
 class Brand(models.Model):
     """A brand : cola-cola, peugeot or whatever"""
     name = models.CharField(max_length=100, verbose_name=_('name'))
@@ -423,12 +465,11 @@ class StoreItem(models.Model):
         return Decimal("{0:.2f}".format(value, 2))
 
     def _to_vat_incl(self, value):
-        if value is None:
-            value = 0
+        value = self._to_decimal(value)
         if self.vat_rate:
             vat_value = self.vat_rate.rate
         else:
-            vat_value = 0
+            vat_value = Decimal(0)
         return self._to_decimal(value * (1 + vat_value / 100))
 
     def vat_incl_price(self):
@@ -906,6 +947,8 @@ class Sale(models.Model):
     analysis_code = models.ForeignKey(
         SaleAnalysisCode, default=None, blank=True, null=True, verbose_name=_("analysis code"), on_delete=models.CASCADE
     )
+    delivery_details = models.TextField(blank=True, default='')  # This may be public (on sale document)
+    details = models.TextField(blank=True, default='')  # This should be private
 
     def get_references_text(self):
         """This text will be added at the bottom of the commercial document"""
@@ -1070,6 +1113,9 @@ class SaleItem(models.Model):
     is_discount = models.BooleanField(
         default=False, verbose_name=_('is discount'), help_text=_('added after total on the bill')
     )
+    is_extra = models.BooleanField(
+        default=False, verbose_name=_('is extra'), help_text=_('added after total on the bill')
+    )
     percentage = models.DecimalField(
         verbose_name=_('percentage'), default=Decimal(100), max_digits=5, decimal_places=2,
         help_text=_('Only a percentage of the item price')
