@@ -19,11 +19,15 @@ def get_cart_type_name():
 
 def get_cart_confirmation_subject(profile, action):
     """returns true if an anonymous can view some data : products, categories, tags"""
-    subject = getattr(settings, 'BALAFON_CART_CONFIRMATION_EMAIL_SUBJECT', _('Purchasing confirmation'))
-    if callable(subject):
-        return subject(profile, action)
+    subject_callback = load_from_module('BALAFON_CART_CONFIRMATION_EMAIL_SUBJECT_CALLBACK', None)
+    if subject_callback is None:
+        subject = getattr(settings, 'BALAFON_CART_CONFIRMATION_EMAIL_SUBJECT', _('Purchasing confirmation'))
+        if callable(subject):
+            return subject(profile, action)
+        else:
+            return subject
     else:
-        return subject
+        return subject_callback(profile, action)
 
 
 def get_cart_processed_callback():
@@ -34,6 +38,15 @@ def get_cart_processed_callback():
     return load_from_module('BALAFON_CART_PROCESSED_CALLBACK', None)
 
 
+def get_notify_cart_callback():
+    """
+    returns a callback defined in BALAFON_NOTIFY_CART_CALLBACK
+    This function should take an action has argument
+    If not defined : notify to user and manager by email
+    """
+    return load_from_module('BALAFON_NOTIFY_CART_CALLBACK', None)
+
+
 def get_thumbnail_size():
     """
     returns size of image when displayed as thumbnail
@@ -60,3 +73,7 @@ def get_image_crop():
     returns size of image when displayed as thumbnail
     """
     return getattr(settings, 'BALAFON_STORE_IMAGE_CROP', None)
+
+
+def get_commercial_document_pdf_options():
+    return getattr(settings, 'BALAFON_COMMERCIAL_DOCUMENT_WKHTMLTOPDF_OPTIONS', None)
