@@ -1,23 +1,24 @@
 # -*- coding: utf-8 -*-
 
+from django.contrib.contenttypes.models import ContentType
 from django import template
-from django.template.base import Variable, VariableDoesNotExist
+from django.urls import reverse
+
 from balafon.Users.forms import UpdateFavoriteForm
 from balafon.Users.models import Favorite
-from django.core.urlresolvers import reverse
-from django.contrib.contenttypes.models import ContentType
 
 register = template.Library()
-    
+
+
 @register.inclusion_tag('Users/_favorite_item.html', takes_context=True)
 def favorite_item(context, object):
-    ct = ContentType.objects.get_for_model(object.__class__)
+    content_type = ContentType.objects.get_for_model(object.__class__)
     user = context['request'].user
-    if user and user.is_authenticated():
+    if user and user.is_authenticated:
         is_in_favorite = Favorite.objects.filter(
-            user = context['request'].user,
-            content_type = ct,
-            object_id = object.id
+            user=context['request'].user,
+            content_type=content_type,
+            object_id=object.id
         ).count()
     else:
         is_in_favorite = 0
@@ -26,4 +27,4 @@ def favorite_item(context, object):
         'status': is_in_favorite,
         'post_url': reverse('users_toggle_favorite'),
         'form': UpdateFavoriteForm(instance=object),
-    }
\ No newline at end of file
+    }
